rulebase.workflow.exact\_match\_labeler module
==============================================

.. automodule:: rulebase.workflow.exact_match_labeler
    :members:
    :undoc-members:
    :show-inheritance:
